Crate behest_tool

Crate behest_tool 

Tool trait, registry, and execution strategies for the behest agent runtime.

Key types

ToolExecutionStrategy

  • Sequential: strict one-at-a-time execution
  • Parallel: concurrent execution with a max concurrency cap
  • Auto: intelligently groups read-only/concurrency-safe tools for parallel execution while serializing stateful tools

Structs

ExecutionPlan
A plan for executing tool calls.
FunctionTool
A closure-based tool.
SideEffects
Side effects a tool may produce.
ToolOutput
The output of a tool execution, wrapping a JSON value.
ToolRegistry
A thread-safe registry of tools.

Enums

ToolError
Canonical tool error type. Aliased here so that downstream callers can write behest_tool::ToolError without taking a direct dependency on behest_core. Errors produced during tool execution.
ToolExecutionStrategy
How tool calls should be executed.

Traits

Tool
An executable tool that can be called by an LLM.

Type Aliases

ToolHandler
Type alias for the async handler function used by FunctionTool.
ToolResult
Alias for a tool execution result.