pub struct ToolRegistry { /* private fields */ }Expand description
A thread-safe registry of tools.
Implementations
Sourceimpl ToolRegistry
impl ToolRegistry
Sourcepub fn register<T: Tool + 'static>(&self, tool: T) -> Option<Arc<dyn Tool>>
pub fn register<T: Tool + 'static>(&self, tool: T) -> Option<Arc<dyn Tool>>
Registers a tool, returning any previous tool with the same name.
Sourcepub fn register_arc(&self, tool: Arc<dyn Tool>) -> Option<Arc<dyn Tool>>
pub fn register_arc(&self, tool: Arc<dyn Tool>) -> Option<Arc<dyn Tool>>
Registers an already-shared tool, returning any previous tool with the same name.
Sourcepub fn specs(&self) -> Vec<ToolSpec>
pub fn specs(&self) -> Vec<ToolSpec>
Generates ToolSpecs for all registered tools, sorted by name.
Sourcepub async fn execute(
&self,
ctx: &dyn ToolContext,
call: &ToolCall,
) -> ToolResult<ToolOutput>
pub async fn execute( &self, ctx: &dyn ToolContext, call: &ToolCall, ) -> ToolResult<ToolOutput>
Looks up and executes a tool call.