pub type ToolHandler = dyn Fn(Value) -> Pin<Box<dyn Future<Output = ToolResult<ToolOutput>> + Send>> + Send + Sync;Expand description
Type alias for the async handler function used by FunctionTool.
pub type ToolHandler = dyn Fn(Value) -> Pin<Box<dyn Future<Output = ToolResult<ToolOutput>> + Send>> + Send + Sync;Type alias for the async handler function used by FunctionTool.